@@ -1,10 +1,7 @@
-from typing import Optional
-
 from fastapi import BackgroundTasks, APIRouter, HTTPException
 from fastapi.encoders import jsonable_encoder
 
 from fastapi_metabot.models import MetabotPayload
-from fastapi_metabot.module import Module
 from fastapi_metabot.utils import current_module, slack_metadata
 
 router = APIRouter()
@@ -16,7 +13,7 @@ async def execute_command(
         payload: MetabotPayload,
         background_tasks: BackgroundTasks,
 ) -> None:
-    module: Optional[Module] = current_module.get()
+    module = current_module.get()
     if module is None:
         raise HTTPException(500)
 
