@@ -1,9 +1,9 @@
 from contextvars import ContextVar
-from typing import Optional, TYPE_CHECKING
+from typing import Optional
+
+from fastapi_metabot.models import SlackMetadata
+from fastapi_metabot.module import Module
 
-if TYPE_CHECKING:
-    from fastapi_metabot.models import SlackMetadata
-    from fastapi_metabot.module import Module
 
 slack_metadata: ContextVar[Optional[SlackMetadata]] = ContextVar(
     'slack_metadata',
